@@ -524,6 +524,14 @@ public:
 	inline T* get(void)
 		{return static_cast<T*>(ArrayReuse::get());};
 
+	/**
+	 * Create a typed object from the heap.  This function blocks when the
+	 * heap is empty until an object is returned to the heap.
+	 * @return typed object pointer from heap.
+	 */
+	inline T* create(void)
+		{return init<T>(static_cast<T*>(ArrayReuse::get()));};
+
 	/**
 	 * Get a typed object from the heap.  This function blocks until the
 	 * the heap has an object to return or the timer has expired.
@@ -533,6 +541,15 @@ public:
 	inline T* get(timeout_t timeout)
 		{return static_cast<T*>(ArrayReuse::get(timeout));};
 
+	/**
+	 * Create a typed object from the heap.  This function blocks until the
+	 * the heap has an object to return or the timer has expired.
+	 * @param timeout to wait for heap in milliseconds.
+	 * @return typed object pointer from heap or NULL if timeout.
+	 */
+	inline T* create(timeout_t timeout)
+		{return init<T>(static_cast<T*>(ArrayReuse::get(timeout)));};
+
 	/**
 	 * Release (return) a typed object back to the heap for re-use.
 	 * @param object to return.
@@ -599,6 +616,15 @@ public:
 	inline T *get(void)
 		{return static_cast<T*>(PagerReuse::get());};
 
+	/**
+	 * Get a typed object from the pager heap.  This function blocks when the
+	 * heap is empty until an object is returned to the heap.  The objects
+	 * default constructor is used.
+	 * @return typed object pointer from heap.
+	 */
+	inline T *create(void)
+		{return init<T>(static_cast<T*>(PagerReuse::get()));};
+
 	/**
 	 * Get a typed object from the heap.  This function blocks until the
 	 * the heap has an object to return or the timer has expired.
@@ -608,6 +634,16 @@ public:
 	inline T *get(timeout_t timeout)
 		{return static_cast<T*>(PagerReuse::get(timeout));};
 
+	/**
+	 * Create a typed object from the heap.  This function blocks until the
+	 * the heap has an object to return or the timer has expired.  The
+	 * objects default constructor is used.
+	 * @param timeout to wait for heap in milliseconds.
+	 * @return typed object pointer from heap or NULL if timeout.
+	 */
+	inline T *create(timeout_t timeout)
+		{return init<T>(static_cast<T*>(PagerReuse::get(timeout)));};
+
 	/**
 	 * Request immediately next available typed object from the pager heap.
 	 * @return typed object pointer or NULL if heap is empty.
